Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(326)

Unified Diff: ash/wm/system_modal_container_layout_manager.h

Issue 2320273002: Refactors DimWindow and moves to ash/common (Closed)
Patch Set: git add wm_window Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/wm/system_modal_container_layout_manager.h
diff --git a/ash/wm/system_modal_container_layout_manager.h b/ash/wm/system_modal_container_layout_manager.h
index 9f20e24249333e40aa8fd6777986e8f3fd70ab54..bdfbb061f35d4a2958193d9032a0c1d9481d14a3 100644
--- a/ash/wm/system_modal_container_layout_manager.h
+++ b/ash/wm/system_modal_container_layout_manager.h
@@ -23,7 +23,7 @@ class Rect;
}
namespace ash {
-class DimWindow;
+class WindowDimmer;
// LayoutManager for the modal window container.
// System modal windows which are centered on the screen will be kept centered
@@ -36,7 +36,7 @@ class ASH_EXPORT SystemModalContainerLayoutManager
explicit SystemModalContainerLayoutManager(aura::Window* container);
~SystemModalContainerLayoutManager() override;
- bool has_modal_background() const { return modal_background_ != NULL; }
+ bool has_window_dimmer() const { return window_dimmer_ != nullptr; }
// Overridden from SnapToPixelLayoutManager:
void OnWindowResized() override;
@@ -97,9 +97,9 @@ class ASH_EXPORT SystemModalContainerLayoutManager
// The container that owns the layout manager.
aura::Window* container_;
- // A window that dims the windows behind the modal window(s) being
- // shown in |container_|.
- DimWindow* modal_background_;
+ // WindowDimmer used to dim windows behind the modal window(s) being shown in
+ // |container_|.
+ WindowDimmer* window_dimmer_ = nullptr;
// A stack of modal windows. Only the topmost can receive events.
std::vector<aura::Window*> modal_windows_;

Powered by Google App Engine
This is Rietveld 408576698